| bend_eff | R Documentation |
In order to run this function, first produce a particle distribution with the 'particle_dist' function, then produce a parameter set with the 'set_params' function. Both of these results must be stored as per examples described in the help set with each.
bend_eff(df, params, method = "Zhang", bend_angle, bend_radius, elnum)
df |
is the particle data set (data frame) established with the 'particle_dist' function |
params |
is the parameter data set for parameters that are not particle size-dependent |
method |
choice of models: Pui or Zhang. Zhang is the default. |
bend_angle |
bend angle in degrees |
bend_radius |
bend radius in m |
elnum |
element number to provide unique column names |
data frame containing original particle distribution with added data for this element
Pusheng Zhang, Randy M. Roberts, André Bénard, Computational guidelines and an empirical model for particle deposition in curved pipes using an Eulerian-Lagrangian approach, Journal of Aerosol Science, Volume 53, 2012, Pages 1-20,ISSN 0021-8502, <doi:10.1016/j.jaerosci.2012.05.007>
David Y. H. Pui, Francisco Romay-Novas & Benjamin Y. H. Liu (1987) Experimental Study of Particle Deposition in Bends of Circular Cross Section, Aerosol Science and Technology, 7:3, 301-315, <doi:10.1080/02786828708959166>
df <- particle_dist() # set up particle distribution
params <- set_params_1("D_tube" = 2.54, "Q_lpm" = 100,
"T_C" = 25, "P_kPa" = 101.325) #example system parameters
df <- set_params_2(df, params) #particle size-dependent parameters
df <- probe_eff(df, params, orient = 'h') #probe orientation - horizontal
df <- bend_eff(df, params, method='Zhang', bend_angle=90,
bend_radius=0.1, elnum=3)
head(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.