report_cum_plots: report on cumulative transport system efficiency (discrete particle sizes only)
Description
In order to run a report, first produce a model of each individual
element. Start with producing a particle distribution
with the `particle_dist` function, then produce a parameter set with
the `set_params` function. Both of these results must be stored as
per examples described in the help set with each. Next, add elements
in the sample system until all are complete.
Usage
report_cum_plots(df, micron)
Value
A plot of cumulative transport efficiencies is generated in a plot window
Arguments
df
is the particle data set - after transport analysis by element
micron
selects the particle size (aerodynamic mass activity
diameter in micrometers). This must be selected from the original
distribution of particles that were started with the `particle_dist`
function.